package com.poststats.golf.rs.api;

import java.util.List;

import com.poststats.golf.rs.api.model.EventDocument;

import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.responses.ApiResponse;
import io.swagger.v3.oas.annotations.responses.ApiResponses;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.validation.constraints.NotNull;
import jakarta.validation.constraints.Positive;
import jakarta.ws.rs.GET;
import jakarta.ws.rs.POST;
import jakarta.ws.rs.Path;
import jakarta.ws.rs.PathParam;
import jakarta.ws.rs.Produces;

/**
 * @author brian.long@poststats.com
 */
@Path("/golf/event/{eventId}")
@Tag(name = "Event Round API")
public interface EventDocumentApi {

	@GET
	@Path("/document/{documentId:[0-9]+}")
	@Produces(Constants.V1_JSON)
	@Operation(
			summary = "Retrieves limited meta-data about the specified document.",
			description = "Retreives name, location, dates, and other direct meta-data about the specified document."
	)
	@ApiResponses({
			@ApiResponse(responseCode = "200", description = "Success"),
			@ApiResponse(
					responseCode = "404",
					description = "An event or event round with the specified ID could not be found"
			)
	})
	EventDocument getOne(
			@Parameter(description = "A unique identifier for an event")
			@NotNull @Positive @PathParam("eventId") long eventId,
			@Parameter(description = "A unique identifier for an event document")
			@NotNull @Positive @PathParam("documentId") long documentId);

	@GET
	@Path("/documents")
	@Produces(Constants.V1_JSON)
	@Operation(
			summary = "Retrieves limited meta-data about all the documents in the specified event.",
			description = "Retreives name, location, dates, and other direct meta-data about all the documents in the specified event."
	)
	@ApiResponses({
			@ApiResponse(responseCode = "200", description = "Success"),
			@ApiResponse(
					responseCode = "404",
					description = "An event with the specified ID or any event documents could not be found"
			)
	})
	List<EventDocument> getAll(@Parameter(description = "A unique identifier for an event")
	@NotNull @Positive @PathParam("eventId") long eventId);

	@POST
	@Path("/document/{documentId:[0-9]+}/sendAgenda")
	@Produces(Constants.V1_JSON)
	@Operation(summary = "Sends the specified agenda immediately.")
	@ApiResponses({
			@ApiResponse(responseCode = "200", description = "Success"),
			@ApiResponse(
					responseCode = "404",
					description = "A document with the specified ID in the specified event could not be found"
			)
	})
	void sendAgenda(
			@Parameter(description = "A unique identifier for an event")
			@NotNull @Positive @PathParam("eventId") long eventId,
			@Parameter(description = "A unique identifier for an event document")
			@NotNull @Positive @PathParam("documentId") long documentId);

	@POST
	@Path("/document/{documentId:[0-9]+}/sendAgenda/{personId:[0-9]+}")
	@Produces(Constants.V1_JSON)
	@Operation(summary = "Sends the specified agenda immediately.")
	@ApiResponses({
			@ApiResponse(responseCode = "200", description = "Success"),
			@ApiResponse(
					responseCode = "404",
					description = "A document with the specified ID in the specified event could not be found"
			)
	})
	void sendAgenda(
			@Parameter(description = "A unique identifier for an event")
			@NotNull @Positive @PathParam("eventId") long eventId,
			@Parameter(description = "A unique identifier for an event document")
			@NotNull @Positive @PathParam("documentId") long documentId,
			@Parameter(description = "A unique identifier for a person")
			@NotNull @Positive @PathParam("personId") long personId);

}
