package com.poststats.golf.rs.api;

import com.poststats.golf.rs.api.model.Golfer;

import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.responses.ApiResponse;
import io.swagger.v3.oas.annotations.responses.ApiResponses;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.validation.constraints.NotNull;
import jakarta.validation.constraints.Positive;
import jakarta.ws.rs.GET;
import jakarta.ws.rs.Path;
import jakarta.ws.rs.PathParam;
import jakarta.ws.rs.Produces;

/**
 * @author brian.long@poststats.com
 */
@Path("/golfer/{personId:[0-9]+}")
@Tag(name = "Golfer API")
@ApiResponses({
		@ApiResponse(responseCode = "200", description = "Success"),
		@ApiResponse(responseCode = "404", description = "A golfer with the specified ID could not be found")
})
public interface GolferApi {

	@GET
	@Produces(Constants.V1_JSON)
	@Operation(
			summary = "Retrieves limited meta-data about a golfer.",
			description = "Retreives name, location, and other direct meta-data about the specified golfer."
	)
	Golfer get(@NotNull @Positive @PathParam("personId") long personId);

}
