package com.poststats.golf.rs.api;

import java.math.BigInteger;

import com.poststats.golf.rs.api.model.Round;

import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.responses.ApiResponse;
import io.swagger.v3.oas.annotations.responses.ApiResponses;
import io.swagger.v3.oas.annotations.security.SecurityRequirement;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.annotation.security.RolesAllowed;
import jakarta.validation.constraints.NotNull;
import jakarta.validation.constraints.Positive;
import jakarta.ws.rs.GET;
import jakarta.ws.rs.PUT;
import jakarta.ws.rs.Path;
import jakarta.ws.rs.PathParam;
import jakarta.ws.rs.Produces;

/**
 * @author brian.long@poststats.com
 */
@Path("/golf/round/{roundId}")
@Tag(name = "Round API")
@ApiResponses({
		@ApiResponse(responseCode = "200", description = "Success"),
		@ApiResponse(responseCode = "404", description = "A round with the specified ID could not be found")
})
public interface RoundApi {

	@GET
	@Produces(Constants.V1_JSON)
	@Operation(summary = "Retrieves limited meta-data about a round.")
	Round get(@NotNull @Positive @PathParam("roundId") BigInteger roundId);

	@PUT
	@Path("/recompute")
	@RolesAllowed(Constants.ADMIN_ROLE)
	@SecurityRequirement(name = "basic")
	@Operation(summary = "Recomputes a round's score and its impact on leaderboards and future handicaps.")
	void recompute(@NotNull @Positive @PathParam("roundId") BigInteger roundId);

}
