package com.poststats.golf.rs.api;

import java.util.List;

import com.poststats.golf.rs.api.model.Event;
import com.poststats.golf.rs.api.model.Series;

import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.responses.ApiResponse;
import io.swagger.v3.oas.annotations.responses.ApiResponses;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.validation.constraints.NotNull;
import jakarta.validation.constraints.Positive;
import jakarta.ws.rs.GET;
import jakarta.ws.rs.Path;
import jakarta.ws.rs.PathParam;
import jakarta.ws.rs.Produces;
import jakarta.ws.rs.QueryParam;

/**
 * @author brian.long@poststats.com
 */
@Path("/golf/series/{seriesId}")
@Tag(name = "Event Series API")
public abstract class SeriesApi {

	@NotNull
	@Positive
	@PathParam("seriesId")
	private int seriesId;

	protected int getSeriesId() {
		return this.seriesId;
	}

	@GET
	@Produces(Constants.V1_JSON)
	@Operation(
			summary = "Retrieves meta-data about an event series.",
			description = "Retreives name and other direct meta-data about the specified event series."
	)
	@ApiResponses({
			@ApiResponse(responseCode = "200", description = "Success"),
			@ApiResponse(responseCode = "404", description = "An event series with the specified ID could not be found")
	})
	public abstract Series get();

	@GET
	@Path("/events")
	@Produces(Constants.V1_JSON)
	@Operation(
			summary = "Retrieves limited event meta-data about all events in an event series.",
			description = "Retreives name, location, dates, and other direct meta-data about all events in the specified event series."
	)
	@ApiResponses({
			@ApiResponse(responseCode = "200", description = "Success"),
			@ApiResponse(responseCode = "404", description = "An event series with the specified ID could not be found")
	})
	public abstract List<Event> getEvents(@QueryParam("reverse") Boolean reverse);

}
