package com.poststats.golf.rs.api.model;

import java.time.LocalDate;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.poststats.golf.rs.api.Constants;
import com.poststats.rs.api.annotation.MapCondition;
import com.poststats.rs.api.annotation.MapEntry;
import com.poststats.rs.api.model.PeriodConstrainable;

@JsonIgnoreProperties(ignoreUnknown = true)
public class CourseTee extends BaseCourseTee<CourseTee>
		implements ReferenceableCourseTee, PeriodConstrainable<LocalDate> {

	@JsonProperty(required = true, access = JsonProperty.Access.READ_ONLY)
	@MapEntry("teeID")
	private long id;

	@JsonProperty
	@MapEntry("liveline")
	@MapCondition(rolesAllowed = {
			Constants.ADMIN_ROLE, "course"
	})
	private LocalDate liveline;

	@JsonProperty
	@MapEntry("deadline")
	@MapCondition(rolesAllowed = {
			Constants.ADMIN_ROLE, "course"
	})
	private LocalDate deadline;

	@JsonProperty
	@MapEntry
	private Course course;

	@JsonProperty
	@MapEntry("courseID")
	private Integer courseId;

	@Override
	public long getId() {
		return id;
	}

	public void setId(long id) {
		this.id = id;
	}

	@Override
	public LocalDate getLiveline() {
		return liveline;
	}

	@Override
	public void setLiveline(LocalDate liveline) {
		this.liveline = liveline;
	}

	@Override
	public LocalDate getDeadline() {
		return deadline;
	}

	@Override
	public void setDeadline(LocalDate deadline) {
		this.deadline = deadline;
	}

	public Course getCourse() {
		return course;
	}

	public void setCourse(Course course) {
		this.course = course;
	}

	public Integer getCourseId() {
		return courseId;
	}

	public void setCourseId(Integer courseId) {
		this.courseId = courseId;
	}

	public CourseTee withId(int id) {
		this.id = id;
		return this;
	}

	public CourseTee withLiveline(LocalDate liveline) {
		this.liveline = liveline;
		return this;
	}

	public CourseTee withDeadline(LocalDate deadline) {
		this.deadline = deadline;
		return this;
	}

	public CourseTee withCourse(Course course) {
		this.course = course;
		return this;
	}

	public CourseTee withCourseId(Integer courseId) {
		this.courseId = courseId;
		return this;
	}

}
