package com.poststats.golf.rs.api.model;

import java.time.LocalDate;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonProperty.Access;
import com.poststats.golf.rs.api.Constants;
import com.poststats.rs.api.annotation.GeocodeSource;
import com.poststats.rs.api.annotation.GeocodeTarget;
import com.poststats.rs.api.annotation.GeocodeTarget.GeocodeField;
import com.poststats.rs.api.annotation.MapCondition;
import com.poststats.rs.api.annotation.MapEntry;

/**
 * @author brian.long@poststats.com
 */
@JsonIgnoreProperties(ignoreUnknown = true)
public class Event extends BaseEvent<Event> implements ReferenceableEvent {

	@JsonProperty(required = true, access = Access.READ_ONLY)
	@MapEntry("eventID")
	private long id;

	@JsonProperty("begins")
	@MapEntry
	private LocalDate liveline;

	@JsonProperty("ends")
	@MapEntry
	private LocalDate deadline;

	@MapEntry
	@GeocodeTarget(GeocodeField.City)
	private String addrcity;

	@MapEntry
	@GeocodeTarget(GeocodeField.State)
	private String addrstate;

	@MapEntry
	@GeocodeTarget(GeocodeField.Country)
	private String addrcountry;

	@MapEntry
	@GeocodeTarget(GeocodeField.FuzzyPostalAddress)
	private String addrfuzzy;

	@JsonProperty
	@MapEntry
	private Series series;

	@JsonProperty(access = Access.READ_ONLY)
	@MapEntry("seriesID")
	private Integer seriesId;

	@JsonProperty
	@MapEntry
	private Boolean financesEnabled;

	@JsonProperty
	@MapEntry
	private Boolean optionsEnabled;

	@JsonProperty
	@MapEntry
	private Boolean notebookEnabled;

	@JsonProperty
	@MapEntry
	private Boolean calendarEnabled;

	@JsonProperty
	@MapEntry
	private Boolean pairingsEnabled;

	@JsonProperty
	@MapEntry
	private Boolean teamsEnabled;

	@JsonProperty
	@MapEntry
	private Boolean lodgingEnabled;

	@JsonProperty
	@MapEntry
	private Boolean documentsEnabled;

	@JsonProperty
	@MapEntry
	private Boolean awardsEnabled;

	@JsonProperty
	@MapEntry
	private Boolean specialHolesEnabled;

	@JsonProperty
	@MapEntry
	private Boolean courseHandicapEnabled;

	@JsonProperty
	@MapEntry
	@MapCondition(rolesAllowed = {
			Constants.EVENT_ROLE_PREFIX
					+ "admin"
	})
	private LocalDate registrationLiveline;

	@JsonProperty
	@MapEntry
	@MapCondition(rolesAllowed = {
			Constants.EVENT_ROLE_PREFIX
					+ "admin"
	})
	private LocalDate registrationHideline;

	@JsonProperty
	@MapEntry
	private LocalDate registrationDeadline;

	@JsonProperty
	@MapEntry
	@MapCondition(rolesAllowed = {
			Constants.EVENT_ROLE_PREFIX
					+ "admin",
			Constants.EVENT_ROLE_PREFIX
					+ "finance"
	})
	private LocalDate financesLiveline;

	@JsonProperty
	@MapEntry
	@MapCondition(rolesAllowed = {
			Constants.EVENT_ROLE_PREFIX
					+ "admin",
			Constants.EVENT_ROLE_PREFIX
					+ "pairing"
	})
	private LocalDate pairingsLiveline;

	@JsonProperty
	@MapEntry
	@MapCondition(rolesAllowed = {
			Constants.EVENT_ROLE_PREFIX
					+ "admin",
			Constants.EVENT_ROLE_PREFIX
					+ "pairing"
	})
	private LocalDate teamsLiveline;

	@JsonProperty
	@MapEntry
	@MapCondition(rolesAllowed = {
			Constants.EVENT_ROLE_PREFIX
					+ "admin",
			Constants.EVENT_ROLE_PREFIX
					+ "options"
	})
	private LocalDate lodgingLiveline;

	@JsonProperty
	@MapEntry
	@MapCondition(rolesAllowed = {
			Constants.EVENT_ROLE_PREFIX
					+ "admin",
			Constants.EVENT_ROLE_PREFIX
					+ "pairing"
	})
	private LocalDate documentsLiveline;

	@JsonProperty
	@MapEntry
	@MapCondition(rolesAllowed = {
			Constants.EVENT_ROLE_PREFIX
					+ "admin",
			Constants.EVENT_ROLE_PREFIX
					+ "pairing"
	})
	private LocalDate specialHolesLiveline;

	@Override
	public long getId() {
		return id;
	}

	public void setId(long id) {
		this.id = id;
	}

	public LocalDate getLiveline() {
		return liveline;
	}

	public void setLiveline(LocalDate liveline) {
		this.liveline = liveline;
	}

	public LocalDate getDeadline() {
		return deadline;
	}

	public void setDeadline(LocalDate deadline) {
		this.deadline = deadline;
	}

	@JsonProperty(access = Access.READ_ONLY)
	@GeocodeSource
	public String getFuzzyLocation() {
		return this.addrfuzzy;
	}

	public Series getSeries() {
		return series;
	}

	public void setSeries(Series series) {
		this.series = series;
	}

	public Integer getSeriesId() {
		return seriesId;
	}

	public void setSeriesId(Integer seriesId) {
		this.seriesId = seriesId;
	}

	public Boolean getAwardsEnabled() {
		return awardsEnabled;
	}

	public void setAwardsEnabled(Boolean awardsEnabled) {
		this.awardsEnabled = awardsEnabled;
	}

	public Boolean getCalendarEnabled() {
		return calendarEnabled;
	}

	public void setCalendarEnabled(Boolean calendarEnabled) {
		this.calendarEnabled = calendarEnabled;
	}

	public Boolean getCourseHandicapEnabled() {
		return courseHandicapEnabled;
	}

	public void setCourseHandicapEnabled(Boolean courseHandicapEnabled) {
		this.courseHandicapEnabled = courseHandicapEnabled;
	}

	public Boolean getDocumentsEnabled() {
		return documentsEnabled;
	}

	public void setDocumentsEnabled(Boolean documentsEnabled) {
		this.documentsEnabled = documentsEnabled;
	}

	public Boolean getFinancesEnabled() {
		return financesEnabled;
	}

	public void setFinancesEnabled(Boolean financesEnabled) {
		this.financesEnabled = financesEnabled;
	}

	public Boolean getLodgingEnabled() {
		return lodgingEnabled;
	}

	public void setLodgingEnabled(Boolean lodgingEnabled) {
		this.lodgingEnabled = lodgingEnabled;
	}

	public Boolean getNotebookEnabled() {
		return notebookEnabled;
	}

	public void setNotebookEnabled(Boolean notebookEnabled) {
		this.notebookEnabled = notebookEnabled;
	}

	public Boolean getOptionsEnabled() {
		return optionsEnabled;
	}

	public void setOptionsEnabled(Boolean optionsEnabled) {
		this.optionsEnabled = optionsEnabled;
	}

	public Boolean getPairingsEnabled() {
		return pairingsEnabled;
	}

	public void setPairingsEnabled(Boolean pairingsEnabled) {
		this.pairingsEnabled = pairingsEnabled;
	}

	public Boolean getSpecialHolesEnabled() {
		return specialHolesEnabled;
	}

	public void setSpecialHolesEnabled(Boolean specialHolesEnabled) {
		this.specialHolesEnabled = specialHolesEnabled;
	}

	public Boolean getTeamsEnabled() {
		return teamsEnabled;
	}

	public void setTeamsEnabled(Boolean teamsEnabled) {
		this.teamsEnabled = teamsEnabled;
	}

	public LocalDate getRegistrationLiveline() {
		return registrationLiveline;
	}

	public void setRegistrationLiveline(LocalDate registrationLiveline) {
		this.registrationLiveline = registrationLiveline;
	}

	public LocalDate getRegistrationHideline() {
		return registrationHideline;
	}

	public void setRegistrationHideline(LocalDate registrationHideline) {
		this.registrationHideline = registrationHideline;
	}

	public LocalDate getRegistrationDeadline() {
		return registrationDeadline;
	}

	public void setRegistrationDeadline(LocalDate registrationDeadline) {
		this.registrationDeadline = registrationDeadline;
	}

	public LocalDate getDocumentsLiveline() {
		return documentsLiveline;
	}

	public void setDocumentsLiveline(LocalDate documentsLiveline) {
		this.documentsLiveline = documentsLiveline;
	}

	public LocalDate getFinancesLiveline() {
		return financesLiveline;
	}

	public void setFinancesLiveline(LocalDate financesLiveline) {
		this.financesLiveline = financesLiveline;
	}

	public LocalDate getLodgingLiveline() {
		return lodgingLiveline;
	}

	public void setLodgingLiveline(LocalDate lodgingLiveline) {
		this.lodgingLiveline = lodgingLiveline;
	}

	public LocalDate getPairingsLiveline() {
		return pairingsLiveline;
	}

	public void setPairingsLiveline(LocalDate pairingsLiveline) {
		this.pairingsLiveline = pairingsLiveline;
	}

	public LocalDate getSpecialHolesLiveline() {
		return specialHolesLiveline;
	}

	public void setSpecialHolesLiveline(LocalDate specialHolesLiveline) {
		this.specialHolesLiveline = specialHolesLiveline;
	}

	public LocalDate getTeamsLiveline() {
		return teamsLiveline;
	}

	public void setTeamsLiveline(LocalDate teamsLiveline) {
		this.teamsLiveline = teamsLiveline;
	}

	public Event withId(long id) {
		this.id = id;
		return this;
	}

	public Event withLiveline(LocalDate liveline) {
		this.liveline = liveline;
		return this;
	}

	public Event withDeadline(LocalDate deadline) {
		this.deadline = deadline;
		return this;
	}

	public Event withSeries(Series series) {
		this.series = series;
		return this;
	}

	public Event withSeriesId(Integer seriesId) {
		this.seriesId = seriesId;
		return this;
	}

	public Event withDocumentsEnabled(Boolean documentsEnabled) {
		this.documentsEnabled = documentsEnabled;
		return this;
	}

	public Event withFinancesEnabled(Boolean financesEnabled) {
		this.financesEnabled = financesEnabled;
		return this;
	}

	public Event withLodgingEnabled(Boolean lodgingEnabled) {
		this.lodgingEnabled = lodgingEnabled;
		return this;
	}

	public Event withNotebookEnabled(Boolean notebookEnabled) {
		this.notebookEnabled = notebookEnabled;
		return this;
	}

	public Event withOptionsEnabled(Boolean optionsEnabled) {
		this.optionsEnabled = optionsEnabled;
		return this;
	}

	public Event withPairingsEnabled(Boolean pairingsEnabled) {
		this.pairingsEnabled = pairingsEnabled;
		return this;
	}

	public Event withSpecialHolesEnabled(Boolean specialHolesEnabled) {
		this.specialHolesEnabled = specialHolesEnabled;
		return this;
	}

	public Event withTeamsEnabled(Boolean teamsEnabled) {
		this.teamsEnabled = teamsEnabled;
		return this;
	}

	public Event withRegistrationLiveline(LocalDate registrationLiveline) {
		this.registrationLiveline = registrationLiveline;
		return this;
	}

	public Event withRegistrationHideline(LocalDate registrationHideline) {
		this.registrationHideline = registrationHideline;
		return this;
	}

	public Event withRegistrationDeadline(LocalDate registrationDeadline) {
		this.registrationDeadline = registrationDeadline;
		return this;
	}

	public Event withDocumentsLiveline(LocalDate documentsLiveline) {
		this.documentsLiveline = documentsLiveline;
		return this;
	}

	public Event withFinancesLiveline(LocalDate financesLiveline) {
		this.financesLiveline = financesLiveline;
		return this;
	}

	public Event withLodgingLiveline(LocalDate lodgingLiveline) {
		this.lodgingLiveline = lodgingLiveline;
		return this;
	}

	public Event withPairingsLiveline(LocalDate pairingsLiveline) {
		this.pairingsLiveline = pairingsLiveline;
		return this;
	}

	public Event withSpecialHolesLiveline(LocalDate specialHolesLiveline) {
		this.specialHolesLiveline = specialHolesLiveline;
		return this;
	}

	public Event withTeamsLiveline(LocalDate teamsLiveline) {
		this.teamsLiveline = teamsLiveline;
		return this;
	}

}
